==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralStringSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralString;
import io.ciera.tool.sql.ooaofooa.value.LiteralStringSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class LiteralStringSetImpl extends InstanceSet<LiteralStringSet,LiteralString> implements LiteralStringSet {

    // attributes
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralString literalstring : this ) literalstring.setValue( m_Value );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralString literalstring : this ) literalstring.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralString literalstring : this ) valueset.add( literalstring.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralString nullElement() {
        return LiteralStringImpl.EMPTY_LITERALSTRING;
    }

    @Override
    public LiteralStringSet emptySet() {
      return new LiteralStringSetImpl();
    }

    @Override
    public LiteralStringSet value() {
        return this;
    }

    @Override
    public List<LiteralString> elements() {
        return Arrays.asList(toArray(new LiteralString[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralStringSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.LiteralString;
import io.ciera.tool.sql.ooaofooa.value.LiteralStringSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LiteralStringSetImpl extends InstanceSet<LiteralStringSet,LiteralString> implements LiteralStringSet {

    public LiteralStringSetImpl() {
    }

    public LiteralStringSetImpl(Comparator<? super LiteralString> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue( String m_Value ) throws XtumlException {
        for ( LiteralString literalstring : this ) literalstring.setValue( m_Value );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( LiteralString literalstring : this ) literalstring.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( LiteralString literalstring : this ) valueset.add( literalstring.R801_is_a_Value() );
        return valueset;
    }


    @Override
    public LiteralString nullElement() {
        return LiteralStringImpl.EMPTY_LITERALSTRING;
    }

    @Override
    public LiteralStringSet emptySet() {
      return new LiteralStringSetImpl();
    }

    @Override
    public LiteralStringSet emptySet(Comparator<? super LiteralString> comp) {
      return new LiteralStringSetImpl(comp);
    }

    @Override
    public LiteralStringSet value() {
        return this;
    }

    @Override
    public List<LiteralString> elements() {
        return Arrays.asList(toArray(new LiteralString[0]));
    }

}
